@@ -31,4 +31,8 @@ class BackendBase:
         if args.uri is None:
             parser.print_help()
             exit()
-        return args
\ No newline at end of file
+        return args
+    
+    def stop(self):
+        self.daemon.shutdown()
+        exit()
\ No newline at end of file
